"""
    EMIL PartnerService

    The EMIL PartnerService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import unittest

import eis.partner
from eis.partner.api.partner_types_api import PartnerTypesApi  # noqa: E501


class TestPartnerTypesApi(unittest.TestCase):
    """PartnerTypesApi unit test stubs"""

    def setUp(self):
        self.api = PartnerTypesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_partner_type(self):
        """Test case for create_partner_type

        Create the partner-types  # noqa: E501
        """
        pass

    def test_delete_partner_type(self):
        """Test case for delete_partner_type

        Delete the partner-types  # noqa: E501
        """
        pass

    def test_get_partner_type(self):
        """Test case for get_partner_type

        Retrieve the partner-types  # noqa: E501
        """
        pass

    def test_list_partner_types(self):
        """Test case for list_partner_types

        List partner-types  # noqa: E501
        """
        pass

    def test_update_partner_type(self):
        """Test case for update_partner_type

        Update the partner-types  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    EMIL PartnerService

    The EMIL PartnerService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import eis.partner
from eis.partner.model.create_partner_relation_request_dto_rest import CreatePartnerRelationRequestDtoRest


class TestCreatePartnerRelationRequestDtoRest(unittest.TestCase):
    """CreatePartnerRelationRequestDtoRest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testCreatePartnerRelationRequestDtoRest(self):
        """Test CreatePartnerRelationRequestDtoRest"""
        # FIXME: construct object with mandatory attributes with example values
        # model = CreatePartnerRelationRequestDtoRest()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
